@@ -83,7 +83,6 @@
 #include "compiler.h"
 #include "xf86Priv.h"
 #include "xf86_OSproc.h"
-#include "xf86Resources.h"
 #include "xf86.h"
 #include "xf86Cursor.h"
 #include "xf86cmap.h"
@@ -114,6 +113,16 @@
 #include <X11/extensions/Xv.h>
 #endif
 
+#include "compat-api.h"
+
+#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 12
+#define _swapl(x, n) swapl(x,n)
+#define _swaps(x, n) swaps(x,n)
+#else
+#define _swapl(x, n) swapl(x)
+#define _swaps(x, n) swaps(x)
+#endif
+
 /* Platform/architecture related definitions: */
 
 #undef SIS_PC_PLATFORM
@@ -142,7 +151,6 @@
 #define UNLOCK_ALWAYS		/* Always unlock the registers (should be set!) */
 
 /* Need that for SiSCtrl */
-#define NEED_REPLIES		/* ? */
 #define EXTENSION_PROC_ARGS void *
 #include "extnsionst.h" 			/* required */
 #include <X11/extensions/panoramiXproto.h>	/* required */
@@ -733,7 +741,7 @@ typedef struct {
     Bool		skipswitchcheck;
     ULong		VBFlagsInit;
     DisplayModePtr	currentModeLast;
-    IOADDRESS		MyPIOOffset;
+    unsigned long		MyPIOOffset;
 
     char		messagebuffer[64];
     unsigned int	VGAMapSize;		/* SiSVGA stuff */
